Actions

Struct Actions 

pub struct Actions<A, S, C> { /* private fields */ }

Implementations

Source

impl<A, S, C> Actions<A, S, C>
where A: Clone + Send + 'static,

pub fn once_epic<E>( &self, epic: E, ) -> impl Future<Output = Result<A, Error>> + use<A, S, C, E>
where E: EpicExt<A, S, C> + Send + 'static,

Wait once the epic emits its first action, remove the epic and return the action. This is guarantted to see all actions that are dispatched after this call has returned the future.

pub fn once<F>( &self, predicate: F, ) -> impl Future<Output = Result<A, Error>> + use<A, S, C, F>
where F: for<'a> Fn(&'a A) -> bool + Send + 'static,

Wait for predicate to match once and return the action it mached. This is guarantted to see all actions that are dispatched after this call has returned the future.

pub fn once_map<F, O>( &self, map: F, ) -> impl Future<Output = Result<O, Error>> + use<A, S, C, F, O>
where F: for<'a> Fn(&'a A) -> Option<O> + Clone + Send + 'static,

Wait for map to match once and return the mapped value of the action. This is guarantted to see all actions that are dispatched after this call has returned the future.