ActorInstance

Struct ActorInstance 

pub struct ActorInstance<A>
where A: Actor,
{ /* private fields */ }
The actual actor instance.

Implementations

Source

impl<A> ActorInstance<A>
where A: Actor,

pub fn handle(&self) -> ActorHandle<A::Message>

Get actor handle.

pub fn tags(&self) -> Tags

Get actor tags.

pub fn shutdown(&self)

Request shutdown.

pub async fn join(self) -> Result<(), ActorError>

Wait until the actor completes.

pub async fn initialized(self) -> Result<ActorHandle<A::Message>, ActorError>

Wait for startup to be complete and then run in background. This will resolve when initialization is done by returning any initialization errors.

pub fn state(&self) -> ActorState

Get actor state.