pub struct Response<T> { /* private fields */ }Expand description
Response.
Notes
- When the response is dropped inside the actor and has not been used we receive a canceled on the caller side.
Implementations
Sourceimpl<T> Response<T>
impl<T> Response<T>
Sourcepub fn respond(self, value: T)
pub fn respond(self, value: T)
Send Response to caller.
Notes
- Ignores when the caller is not waiting for the response. When you want to handle this use
Response::send.
Sourcepub async fn respond_execute<Fut, F>(self, value: F)
pub async fn respond_execute<Fut, F>(self, value: F)
Executes closure and respond with the result
Sourcepub fn send(self, value: T) -> Result<(), ActorError>
pub fn send(self, value: T) -> Result<(), ActorError>
Try to send response to caller.
Errors
- Fails with
ActorError::Canceledwhen the caller is not waiting for the result.
Sourcepub async fn execute<Fut, F>(self, value: F) -> Result<(), ActorError>
pub async fn execute<Fut, F>(self, value: F) -> Result<(), ActorError>
Executes closure and respond with the result
Sourcepub fn spawn_with<Fut, F>(self, spawner: impl Borrow<TaskSpawner>, value: F)
pub fn spawn_with<Fut, F>(self, spawner: impl Borrow<TaskSpawner>, value: F)
Spawns a new task using the given spawner and executes given closure in it
Sourcepub fn spawn_local<Fut, F>(self, spawner: impl LocalTaskSpawner, value: F)
pub fn spawn_local<Fut, F>(self, spawner: impl LocalTaskSpawner, value: F)
Spawns a new task using the given spawner and executes given closure in it