Modules
Structs
- Action
Dispatch - Action Dispatch. Encasulate epic logic in a single future.
- Actions
- Actor
Handle - Handle into an actor which can be used to send messages.
- Actor
Instance - The actual actor instance.
- Actor
Spawner - Actor Spawner with early access to the handle (which allow cyclic references).
- Epic
Runtime - Epic runtime to be uses as actor state. Expected to be called after the message has been applied to the state.
- Join
Epic - Joins two epics into one.
- Local
Actor Instance - The actual actor instance.
- Local
Actor Spawner - Actor Spawner with early access to the handle (which allow cyclic references).
- Merge
Epic - Merge BoxEpic into one.
- Response
- Response.
- Response
Back Pressure Stream - A streaming response with backpressure (bounded).
- Response
Back Pressure Stream Receiver - Response
Receiver - Response
Stream - A streaming response.
- Response
Stream Receiver - Response
Streams - Switch
Epic - Only allow to run epic once. Once the epic returns another stream the previous will be dropped.
- Task
Options - Task
Spawner - Tracing
Epic - Trace actions and state as debug messages.
Enums
Traits
- Actor
- Simple actor model implementation. Accepts messages which will be applied to the actor state. Actor state is different to the actual actor instance in order to allow initialization of it within the actor context.
- Epic
- Epic.
- EpicExt
- Local
Actor - A LocalActor will not moved between threads.
This is sometimes necessary when interfacing with external code.
This trait allows to implement such behaviour with same public interface as a normal [
Actor] (ActorHandle). For new code that dont have this requirement is usually better to use [Actor] as it allows to use multithreading. - Local
Task Spawner - Spawn a local (not Send) future.
- Reducer
- State reducer.