pub struct Actions<A, S, C> { /* private fields */ }Implementations
Sourceimpl<A, S, C> Actions<A, S, C>
impl<A, S, C> Actions<A, S, C>
Sourcepub fn once_epic<E>(
&self,
epic: E,
) -> impl Future<Output = Result<A, Error>> + use<A, S, C, E>
pub fn once_epic<E>( &self, epic: E, ) -> impl Future<Output = Result<A, Error>> + use<A, S, C, E>
Wait once the epic emits its first action, remove the epic and return the action. This is guarantted to see all actions that are dispatched after this call has returned the future.
Sourcepub fn once<F>(
&self,
predicate: F,
) -> impl Future<Output = Result<A, Error>> + use<A, S, C, F>
pub fn once<F>( &self, predicate: F, ) -> impl Future<Output = Result<A, Error>> + use<A, S, C, F>
Wait for predicate to match once and return the action it mached. This is guarantted to see all actions that are dispatched after this call has returned the future.