pub struct ActorInstance<A>where
A: Actor,{ /* private fields */ }Expand description
The actual actor instance.
Implementations
Sourceimpl<A> ActorInstance<A>where
A: Actor,
impl<A> ActorInstance<A>where
A: Actor,
Sourcepub fn handle(&self) -> ActorHandle<A::Message>
pub fn handle(&self) -> ActorHandle<A::Message>
Get actor handle.
Get actor tags.
Sourcepub async fn join(self) -> Result<(), ActorError>
pub async fn join(self) -> Result<(), ActorError>
Wait until the actor completes.
Sourcepub async fn initialized(self) -> Result<ActorHandle<A::Message>, ActorError>
pub async fn initialized(self) -> Result<ActorHandle<A::Message>, ActorError>
Wait for startup to be complete and then run in background. This will resolve when initialization is done by returning any initialization errors.
Sourcepub fn state(&self) -> ActorState
pub fn state(&self) -> ActorState
Get actor state.