pub trait Epic<A, S, C> {
// Required method
fn epic(
&mut self,
actions: &Actions<A, S, C>,
action: &A,
state: &S,
context: &C,
) -> Option<impl Stream<Item = Result<A, Error>> + Send + 'static>;
// Provided method
fn is_terminated(&self) -> bool { ... }
}Expand description
Epic.
Defines side effects for actions which will produce other actions over time.
Required Methods
Provided Methods
Sourcefn is_terminated(&self) -> bool
fn is_terminated(&self) -> bool
Whether this epic is terminated and should be not be called futher.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl<A, S, C> Epic<A, S, C> for MergeEpic<A, S, C>where
A: Send + 'static,
impl<A, S, C> Epic<A, S, C> for TracingEpic
impl<A, S, C, O, F> Epic<A, S, C> for F
Fn impl for epics.